OutputNetworkGenlockSourceGetSet enum
Values
- swaggerGeneratedUnknown → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet(null) - internal → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('internal') - sdi → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('sdi') - sdiA → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('sdi-a') - sdiB → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('sdi-b') - hdmi → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('hdmi') - dvi → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('dvi') - refIn → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('ref-in') - activeInput → const OutputNetworkGenlockSourceGetSet
-
const OutputNetworkGenlockSourceGetSet('active-input')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OutputNetworkGenlockSourceGetSet> - A constant List of the values in this enum, in order of their declaration.