AssociatedCount class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AssociatedCount({int? associatedCount})
AssociatedCount.fromJson(Map<String, dynamic> json)
factory

Properties

associatedCount int?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? associatedCount}) AssociatedCount

Available on AssociatedCount, provided by the $AssociatedCountExtension extension

copyWithWrapped({Wrapped<int?>? associatedCount}) AssociatedCount

Available on AssociatedCount, provided by the $AssociatedCountExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const AssociatedCount Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AssociatedCount instance)