AutoBrighten class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- AutoBrighten({Object? autoBrighten})
-
AutoBrighten.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autoBrighten → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? autoBrighten}) → AutoBrighten -
Available on AutoBrighten, provided by the $AutoBrightenExtension extension
-
copyWithWrapped(
{Wrapped< Object?> ? autoBrighten}) → AutoBrighten -
Available on AutoBrighten, provided by the $AutoBrightenExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const AutoBrighten Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(AutoBrighten instance)