BadRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BadRequest({List<String>? errorMessages, String? responseCode})
BadRequest.fromJson(Map<String, dynamic> json)
factory

Properties

errorMessages List<String>?
final
hashCode int
The hash code for this object.
no setteroverride
responseCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? errorMessages, String? responseCode}) BadRequest

Available on BadRequest, provided by the $BadRequestExtension extension

copyWithWrapped({Wrapped<List<String>?>? errorMessages, Wrapped<String?>? responseCode}) BadRequest

Available on BadRequest, provided by the $BadRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const BadRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BadRequest instance)