BitDepth class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BitDepth({int? bitDepth})
BitDepth.fromJson(Map<String, dynamic> json)
factory

Properties

bitDepth int?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? bitDepth}) BitDepth

Available on BitDepth, provided by the $BitDepthExtension extension

copyWithWrapped({Wrapped<int?>? bitDepth}) BitDepth

Available on BitDepth, provided by the $BitDepthExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const BitDepth Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BitDepth instance)