Brightness class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Brightness({double? brightness})
Brightness.fromJson(Map<String, dynamic> json)
factory

Properties

brightness double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? brightness}) Brightness

Available on Brightness, provided by the $BrightnessExtension extension

copyWithWrapped({Wrapped<double?>? brightness}) Brightness

Available on Brightness, provided by the $BrightnessExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const Brightness Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Brightness instance)