ColourTolerance$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ColourTolerance$Response({double? colourTolerance})
const
ColourTolerance$Response.fromJson(Map<String, dynamic> json)
factory

Properties

colourTolerance double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? colourTolerance}) ColourTolerance$Response

Available on ColourTolerance$Response, provided by the $ColourTolerance$ResponseExtension extension

copyWithWrapped({Wrapped<double?>? colourTolerance}) ColourTolerance$Response

Available on ColourTolerance$Response, provided by the $ColourTolerance$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const ColourTolerance$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ColourTolerance$Response instance)