CustomFrameRate class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CustomFrameRate({double? customFrameRate})
CustomFrameRate.fromJson(Map<String, dynamic> json)
factory

Properties

customFrameRate double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? customFrameRate}) CustomFrameRate

Available on CustomFrameRate, provided by the $CustomFrameRateExtension extension

copyWithWrapped({Wrapped<double?>? customFrameRate}) CustomFrameRate

Available on CustomFrameRate, provided by the $CustomFrameRateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const CustomFrameRate Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CustomFrameRate instance)