DistanceToTracker class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DistanceToTracker({double? distanceToTracker})
DistanceToTracker.fromJson(Map<String, dynamic> json)
factory

Properties

distanceToTracker double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? distanceToTracker}) DistanceToTracker

Available on DistanceToTracker, provided by the $DistanceToTrackerExtension extension

copyWithWrapped({Wrapped<double?>? distanceToTracker}) DistanceToTracker

Available on DistanceToTracker, provided by the $DistanceToTrackerExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const DistanceToTracker Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(DistanceToTracker instance)