FadeTime class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FadeTime({double? fadeTime})
FadeTime.fromJson(Map<String, dynamic> json)
factory

Properties

fadeTime double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? fadeTime}) FadeTime

Available on FadeTime, provided by the $FadeTimeExtension extension

copyWithWrapped({Wrapped<double?>? fadeTime}) FadeTime

Available on FadeTime, provided by the $FadeTimeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const FadeTime Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FadeTime instance)