Fraction class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Fraction({double? fraction})
Fraction.fromJson(Map<String, dynamic> json)
factory

Properties

fraction double?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? fraction}) Fraction

Available on Fraction, provided by the $FractionExtension extension

copyWithWrapped({Wrapped<double?>? fraction}) Fraction

Available on Fraction, provided by the $FractionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const Fraction Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Fraction instance)