FrameRateMultiplier$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FrameRateMultiplier$Response({int? frameRateMultiplier})
const
FrameRateMultiplier$Response.fromJson(Map<String, dynamic> json)
factory

Properties

frameRateMultiplier int?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? frameRateMultiplier}) FrameRateMultiplier$Response

Available on FrameRateMultiplier$Response, provided by the $FrameRateMultiplier$ResponseExtension extension

copyWithWrapped({Wrapped<int?>? frameRateMultiplier}) FrameRateMultiplier$Response

Available on FrameRateMultiplier$Response, provided by the $FrameRateMultiplier$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const FrameRateMultiplier$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FrameRateMultiplier$Response instance)