InternalRate class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- InternalRate({double? internalRate})
-
InternalRate.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- internalRate → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? internalRate}) → InternalRate -
Available on InternalRate, provided by the $InternalRateExtension extension
-
copyWithWrapped(
{Wrapped< double?> ? internalRate}) → InternalRate -
Available on InternalRate, provided by the $InternalRateExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const InternalRate Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(InternalRate instance)