IsActive class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

IsActive({Object? isActive})
IsActive.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isActive Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? isActive}) IsActive

Available on IsActive, provided by the $IsActiveExtension extension

copyWithWrapped({Wrapped<Object?>? isActive}) IsActive

Available on IsActive, provided by the $IsActiveExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const IsActive Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(IsActive instance)