OnButtonPress class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- OnButtonPress({Object? onButtonPress})
-
OnButtonPress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- onButtonPress → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? onButtonPress}) → OnButtonPress -
Available on OnButtonPress, provided by the $OnButtonPressExtension extension
-
copyWithWrapped(
{Wrapped< Object?> ? onButtonPress}) → OnButtonPress -
Available on OnButtonPress, provided by the $OnButtonPressExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const OnButtonPress Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(OnButtonPress instance)