Orientation class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- Orientation({String? orientation})
-
Orientation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- orientation → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? orientation}) → Orientation -
Available on Orientation, provided by the $OrientationExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? orientation}) → Orientation -
Available on Orientation, provided by the $OrientationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const Orientation Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(Orientation instance)