OutputNetworkStartrackerFramesEnabledOnPut$RequestBody class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

data List<Object>
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<Object>? data}) OutputNetworkStartrackerFramesEnabledOnPut$RequestBody

Available on OutputNetworkStartrackerFramesEnabledOnPut$RequestBody, provided by the $OutputNetworkStartrackerFramesEnabledOnPut$RequestBodyExtension extension

copyWithWrapped({Wrapped<List<Object>>? data}) OutputNetworkStartrackerFramesEnabledOnPut$RequestBody

Available on OutputNetworkStartrackerFramesEnabledOnPut$RequestBody, provided by the $OutputNetworkStartrackerFramesEnabledOnPut$RequestBodyExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override