ProcessingColourReplaceStrengthPut$RequestBody class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

data double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? data}) ProcessingColourReplaceStrengthPut$RequestBody

Available on ProcessingColourReplaceStrengthPut$RequestBody, provided by the $ProcessingColourReplaceStrengthPut$RequestBodyExtension extension

copyWithWrapped({Wrapped<double>? data}) ProcessingColourReplaceStrengthPut$RequestBody

Available on ProcessingColourReplaceStrengthPut$RequestBody, provided by the $ProcessingColourReplaceStrengthPut$RequestBodyExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const ProcessingColourReplaceStrengthPut$RequestBody Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ProcessingColourReplaceStrengthPut$RequestBody instance)