RefreshRate class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

RefreshRate({double? refreshRate})
RefreshRate.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
refreshRate double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? refreshRate}) RefreshRate

Available on RefreshRate, provided by the $RefreshRateExtension extension

copyWithWrapped({Wrapped<double?>? refreshRate}) RefreshRate

Available on RefreshRate, provided by the $RefreshRateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const RefreshRate Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(RefreshRate instance)