SensorReadoutTime class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SensorReadoutTime({double? sensorReadoutTime})
SensorReadoutTime.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorReadoutTime double?
final

Methods

copyWith({double? sensorReadoutTime}) SensorReadoutTime

Available on SensorReadoutTime, provided by the $SensorReadoutTimeExtension extension

copyWithWrapped({Wrapped<double?>? sensorReadoutTime}) SensorReadoutTime

Available on SensorReadoutTime, provided by the $SensorReadoutTimeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const SensorReadoutTime Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SensorReadoutTime instance)