Source class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Source({String? source})
Source.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final

Methods

copyWith({String? source}) Source

Available on Source, provided by the $SourceExtension extension

copyWithWrapped({Wrapped<String?>? source}) Source

Available on Source, provided by the $SourceExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const Source Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Source instance)