State class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

State({String? state})
State.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final

Methods

copyWith({String? state}) State

Available on State, provided by the $StateExtension extension

copyWithWrapped({Wrapped<String?>? state}) State

Available on State, provided by the $StateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(dynamic other) bool
The equality operator.
override

Constants

fromJsonFactory → const State Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(State instance)