BlackoutAffectsMarkers class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- BlackoutAffectsMarkers({Object? blackoutAffectsMarkers})
-
BlackoutAffectsMarkers.fromJson(Map<
String, dynamic> json) -
factory
Properties
- blackoutAffectsMarkers → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? blackoutAffectsMarkers}) → BlackoutAffectsMarkers -
Available on BlackoutAffectsMarkers, provided by the $BlackoutAffectsMarkersExtension extension
-
copyWithWrapped(
{Wrapped< Object?> ? blackoutAffectsMarkers}) → BlackoutAffectsMarkers -
Available on BlackoutAffectsMarkers, provided by the $BlackoutAffectsMarkersExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
dynamic other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const BlackoutAffectsMarkers Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(BlackoutAffectsMarkers instance)